API docs for “spamfighter.core.commands.partner”

# Module s.c.c.partner

Part of spamfighter.core.commands View Source

Команды с поддержкой выбора партнера и домена.

Class | IPartnerAuthInfo | Информация об авторизации партнера.
Class | PartnerAuthInfo | Класс, хранящий информации об авторизации партнера.
Class | CommandParamMergerMeta | Мета-тип, который собирает вместе сигнатуру
Class | PartneredCommand | Команда, обязательным параметром которой является партнер.
Class | DomainedCommand | Команда, которая в качестве параметра может содержать путь к поддомену,